# -*- coding: utf-8 -*-
import re

from django import template

from account.forms import LoginForm


register = template.Library()

@register.tag(name='get_login_form')
def do_get_login_form(parser, token):
    try:
        tag_name, arg = token.contents.split(None, 1)
    except ValueError:
        raise template.TemplateSyntaxError, "%r tag requires arguments" % token.contents.split()[0]

    match = re.search(r'as\s+(\w+)', arg)
    if not match:
        raise template.TemplateSyntaxError, "%r tag had invalid arguments" % tag_name
    name = match.group(1)

    return GetLoginFormNode(name)


class GetLoginFormNode(template.Node):
    def __init__(self, name):
        self.name = name

    def render(self, context):
        context[self.name] = LoginForm(request=context['request'])
        return ''



from django.contrib import auth
from django.dispatch import Signal
from django.contrib.sites.models import Site

from urlauth.signals import key_user_found
from urlauth.models import AuthKey

from account.util import email_template

account_created = Signal(providing_args=['user'])

def key_user_found_handler(key, user, **kwargs):
    extra = key.extra
    action = extra.get('action')

    if 'activation' == action:
        if not user.is_active:
            user.is_active = True
            user.save()
            email_template(user.email, 'account/mail/welcome',
                           user=user, domain=Site.objects.get_current().domain)

    if user.is_active:
        if 'new_email' == action:
            if 'email' in extra:
                user.email = args['email']
                user.save()


key_user_found.connect(key_user_found_handler, sender=AuthKey)
